pub struct Pid { /* private fields */ }Expand description
A unique hashable ID used to identify puppets.
Pid is similar to Id but includes an additional name_fn field that
provides a way to retrieve the name of the puppet type statically.
Implementations
Sourceimpl Pid
impl Pid
Sourcepub fn new<P>() -> Selfwhere
P: Puppet,
pub fn new<P>() -> Selfwhere
P: Puppet,
Creates a new Pid instance for the given puppet type P.
This function generates a unique Pid based on the Id of the puppet
type P and assigns the _name function as the name_fn field.
Panics
This function does not panic.